@@ -3,6 +3,9 @@
 #include "mainwindow.h"
 #include <QGraphicsScene>
 #include <QtGui>
+#include <QProcess>
+#include <QGraphicsProxyWidget>
+
 
 bool gameStarted = false;
 
@@ -21,6 +24,11 @@ WelcomeScreen::WelcomeScreen(QWidget *parent) :
 
     ui->lblLogo->setAlignment(Qt::AlignCenter);
 
+    QTimer *blight = new QTimer;
+    blight->setInterval(30000);
+    blight->start();
+    connect(blight,SIGNAL(timeout()),this, SLOT(keepBacklightOn()));
+
 }
 
 WelcomeScreen::~WelcomeScreen()
@@ -68,6 +76,7 @@ void WelcomeScreen::on_pushButton_clicked()
     ui->pushButton->setText("Continue");
     ui->pushButton_2->setEnabled(true);
 
+
     scene->addItem(w);
 
 
@@ -77,6 +86,8 @@ void WelcomeScreen::on_pushButton_clicked()
     view->setCacheMode(QGraphicsView::CacheBackground);
     view->setViewportUpdateMode(QGraphicsView::BoundingRectViewportUpdate);
     view->setDragMode(QGraphicsView::ScrollHandDrag);
+    //Will enable fullscreen once i get proper menus in place
+    //view->showFullScreen();
     view->show();
 
 
@@ -155,3 +166,11 @@ void WelcomeScreen::on_pushButton_2_clicked()
     timer->start();
     connect(timer,SIGNAL(timeout()),scene, SLOT(advance()));
 }
+
+void WelcomeScreen::keepBacklightOn()
+{
+    QString backlightMessage = "dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_display_blanking_pause";
+
+    QProcess *myProcess = new QProcess(this);
+    myProcess->start(backlightMessage);
+}
