@@ -15,6 +15,9 @@ public:
     explicit WelcomeScreen(QWidget *parent = 0);
     ~WelcomeScreen();
 
+public slots:
+    void keepBacklightOn();
+
 private:
     Ui::WelcomeScreen *ui;
 
@@ -22,6 +25,7 @@ private slots:
     void on_pushButton_2_clicked();
     void on_comboBox_currentIndexChanged(int index);
     void on_pushButton_clicked();
+
 };
 
 #endif // WELCOMESCREEN_H
